summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--net/http/http_network_transaction.h2
-rw-r--r--net/http/http_network_transaction_unittest.cc4
2 files changed, 3 insertions, 3 deletions
diff --git a/net/http/http_network_transaction.h b/net/http/http_network_transaction.h
index fde2152..59685ab5 100644
--- a/net/http/http_network_transaction.h
+++ b/net/http/http_network_transaction.h
@@ -371,7 +371,7 @@ class HttpNetworkTransaction : public HttpTransaction {
// grow to. If the body start is not found within this range of the
// response, the transaction will fail with ERR_RESPONSE_HEADERS_TOO_BIG.
// Note: |kMaxHeaderBufSize| should be a multiple of |kHeaderBufInitialSize|.
- enum { kMaxHeaderBufSize = 32768 }; // 32 kilobytes.
+ enum { kMaxHeaderBufSize = 256 * 1024 }; // 256 kilobytes.
// The size in bytes of the buffer we use to drain the response body that
// we want to throw away. The response body is typically a small error
diff --git a/net/http/http_network_transaction_unittest.cc b/net/http/http_network_transaction_unittest.cc
index 69f8c5b..a3a4647 100644
--- a/net/http/http_network_transaction_unittest.cc
+++ b/net/http/http_network_transaction_unittest.cc
@@ -1816,9 +1816,9 @@ TEST_F(HttpNetworkTransactionTest, LargeHeadersNoBody) {
request.url = GURL("http://www.google.com/");
request.load_flags = 0;
// Respond with 50 kb of headers (we should fail after 32 kb).
std::string large_headers_string;
- FillLargeHeadersString(&large_headers_string, 50 * 1024);
+ FillLargeHeadersString(&large_headers_string, 300 * 1024);
MockRead data_reads[] = {
MockRead("HTTP/1.0 200 OK\r\n"),
@@ -1816,9 +1816,9 @@ TEST_F(HttpNetworkTransactionTest, LargeHeadersNoBody) {
request.url = GURL("http://www.google.com/");
request.load_flags = 0;
- // Respond with 50 kb of headers (we should fail after 32 kb).
+ // Respond with 300 kb of headers (we should fail after 256 kb).
std::string large_headers_string;